]> Shamusworld >> Repos - rmac/blobdiff - rmac.h
Fix to prevent defined registers/CCs from being exported in the symtab.
[rmac] / rmac.h
diff --git a/rmac.h b/rmac.h
index 52fb92ddd355621645fe812b9f60a6839d74baa2..0dd9865a512eac30789696a682d94b2684c60c60 100644 (file)
--- a/rmac.h
+++ b/rmac.h
@@ -1,7 +1,7 @@
 //
-// RMAC - Reboot's Macro Assembler for all Atari computers
+// RMAC - Renamed Macro Assembler for all Atari computers
 // RMAC.H - Main Application Code
-// Copyright (C) 199x Landon Dyer, 2011-2020 Reboot and Friends
+// Copyright (C) 199x Landon Dyer, 2011-2022 Reboot and Friends
 // RMAC derived from MADMAC v1.07 Written by Landon Dyer, 1986
 // Source utilised with the kind permission of Landon Dyer
 //
@@ -27,6 +27,7 @@
        #define _OPEN_FLAGS     _O_TRUNC|_O_CREAT|_O_BINARY|_O_RDWR
        #define _OPEN_INC       _O_RDONLY|_O_BINARY
        #define _PERM_MODE      _S_IREAD|_S_IWRITE
+    #define PATH_SEPS       ";"
 
        #ifdef _MSC_VER
                #if _MSC_VER > 1000
@@ -38,7 +39,6 @@
        #define STRINGIZE(x) STRINGIZE_HELPER(x)
        #define WARNING(desc) __pragma(message(__FILE__ "(" STRINGIZE(__LINE__) ") : Warning: " #desc))
        #define inline __inline
-
        // usage:
        // WARNING(FIXME: Code removed because...)
 
@@ -64,6 +64,7 @@
        #define _OPEN_FLAGS     O_TRUNC|O_CREAT|O_RDWR
        #define _OPEN_INC       O_RDONLY
        #define _PERM_MODE      S_IRUSR|S_IWUSR
+    #define PATH_SEPS       ";:"
 
        #ifdef __MINGW32__
        #define off64_t long
@@ -86,6 +87,7 @@
        #define _OPEN_FLAGS     O_TRUNC|O_CREAT|O_RDWR
        #define _OPEN_INC       O_RDONLY
        #define _PERM_MODE      S_IREAD|S_IWRITE
+    #define PATH_SEPS       ":;"
        // Defined here, even though the platform may not support it...
        #define DO_PRAGMA(x) _Pragma (#x)
        #define WARNING(desc) DO_PRAGMA(message (#desc))
 // Non-target specific stuff
 //
 #include <inttypes.h>
+#include <dirent.h>
 #include "symbol.h"
 
+#if defined(WIN32) || defined(WIN64)
+// Ever since Visual Studio... 2017? 2019? the following constants come defined in the
+// platform SDK, which leads to endless warnings from the compiler. So let's just
+// put the pacifier on and undef them, sheesh! (No, we won't rename the defines,
+// we've been here since 1986, Visual Studio wasn't even a glimpse in the milkman's eyes,
+// if you catch my drift)
+#undef CONST
+#undef ERROR
+#undef TEXT
+#endif
+
 #define BYTE         uint8_t
 #define WORD         uint16_t
 #define LONG         uint32_t
 enum
 {
 ALCYON,                                // Alcyon/DRI C object format
-MWC,                           // Mark Williams object format
 BSD,                           // BSD object format
 ELF,                           // ELF object format
 LOD,                           // DSP 56001 object format
 P56,                           // DSP 56001 object format
 XEX,                           // COM/EXE/XEX/whatever a8 object format
+RAW,                           // Output at absolute address
 };
 
 // Assembler token
@@ -245,52 +259,31 @@ PTR
 #define SIZP         0x0080            // .p (FPU pakced decimal real)
 #define SIZQ         0x0100            // .q (quad word)
 
-// RISC register bank definitions (used in extended symbol attributes also)
-#define BANK_N       0x0000            // No register bank specified
-#define BANK_0       0x0001            // Register bank zero specified
-#define BANK_1       0x0002            // Register bank one specified
 #define EQUATEDREG   0x0008            // Equated register symbol
 #define UNDEF_EQUR   0x0010
 #define EQUATEDCC    0x0020
 #define UNDEF_CC     0x0040
 
-// Construct binary constants at compile time
-// Code by Tom Torfs
-
-// Helper macros
-#define HEX__(n) 0x##n##LU
-#define B8__(x) \
- ((x&0x0000000FLU)?1:0) \
-+((x&0x000000F0LU)?2:0) \
-+((x&0x00000F00LU)?4:0) \
-+((x&0x0000F000LU)?8:0) \
-+((x&0x000F0000LU)?16:0) \
-+((x&0x00F00000LU)?32:0) \
-+((x&0x0F000000LU)?64:0) \
-+((x&0xF0000000LU)?128:0)
-
-// User macros
-#define B8(d) ((uint8_t)B8__(HEX__(d)))
-#define B16(dmsb,dlsb) (((uint16_t)B8(dmsb)<<8) + B8(dlsb))
-#define B32(dmsb,db2,db3,dlsb) (((uint32_t)B8(dmsb)<<24) \
-+ ((uint32_t)B8(db2)<<16) \
-+ ((uint32_t)B8(db3)<<8) \
-+ B8(dlsb))
-
 // Optimisation defines
 enum
 {
+    // These will be set to on/off when .opt "+Oall"/"~Oall" is called
        OPT_ABS_SHORT     = 0,
        OPT_MOVEL_MOVEQ   = 1,
        OPT_BSR_BCC_S     = 2,
-       OPT_INDIRECT_DISP = 3,
+       OPT_OUTER_DISP    = 3,
        OPT_LEA_ADDQ      = 4,
-       OPT_BASE_DISP     = 5,
+       OPT_020_DISP      = 5,          // 020+ base and outer displacements (bd, od) absolute long to short
        OPT_NULL_BRA      = 6,
        OPT_CLR_DX        = 7,
        OPT_ADDA_ADDQ     = 8,
        OPT_ADDA_LEA      = 9,
-       OPT_COUNT   // Dummy, used to count number of optimisation switches
+       OPT_56K_SHORT     = 10,
+       OPT_56K_AUTO_LONG = 11,
+       OPT_COUNT,                  // Dummy, used to count number of optimisation switches
+    // These will be unaffected by "Oall"
+       OPT_PC_RELATIVE   = 30,         // Enforce PC relative
+    OPT_COUNT_ALL               // Dummy, used to count all switches
 };
 
 // Exported variables
@@ -301,23 +294,27 @@ extern int robjproc;
 extern int dsp56001;
 extern int err_flag;
 extern int err_fd;
-extern int regbank;
 extern char * firstfname;
 extern int list_fd;
 extern int list_pag;
-extern int as68_flag;
 extern int m6502;
 extern int list_flag;
 extern int glob_flag;
 extern int lsym_flag;
-extern int sbra_flag;
+extern int optim_warn_flag;
 extern int obj_format;
 extern int legacy_flag;
 extern int prg_flag;   // 1 = write ".PRG" relocatable executable
 extern LONG PRGFLAGS;
-extern int optim_flags[OPT_COUNT];
+extern int optim_flags[OPT_COUNT_ALL];
 extern int activecpu;
 extern int activefpu;
+extern uint32_t org68k_address;
+extern int org68k_active;
+extern int *regbase;
+extern int *regtab;
+extern int *regcheck;
+extern int *regaccept;
 
 // Exported functions
 void strtoupper(char * s);